@@ -48,6 +48,9 @@ fn main() {
     let msvc = target.contains("msvc");
     let mut cfg = cmake::Config::new("libgit2");
 
+    #[cfg(feature = "ssh_key_from_memory")] 
+    cfg.define("GIT_SSH_MEMORY_CREDENTIALS", "1");
+
     if msvc {
         // libgit2 passes the /GL flag to enable whole program optimization, but
         // this requires that the /LTCG flag is passed to the linker later on,
@@ -70,13 +73,15 @@ fn main() {
     // windows as libssh2 doesn't come with a libssh2.pc file in that install
     // (or when pkg-config isn't found). As a result we just manually turn on
     // SSH support in libgit2 (a little jankily) here...
+    let mut ssh_forced = false;
     if ssh && (windows || !has_pkgconfig) {
         if let Ok(libssh2_include) = env::var("DEP_SSH2_INCLUDE") {
+            ssh_forced = true;
             if msvc {
                 cfg.cflag(format!("/I{}", libssh2_include))
                    .cflag("/DGIT_SSH");
             } else {
-                cfg.cflag(format!("-I{}", libssh2_include))
+                cfg.cflag(format!("-I{}", sanitize_sh(libssh2_include.as_ref())))
                    .cflag("-DGIT_SSH");
             }
         }
@@ -118,6 +123,11 @@ fn main() {
         cfg.define("CURL", "OFF");
     }
 
+    //Use bundled http-parser if cross compiling
+    if host != target {
+        cfg.define("USE_EXT_HTTP_PARSER", "OFF");
+    }
+
     let _ = fs::remove_dir_all(env::var("OUT_DIR").unwrap());
     t!(fs::create_dir_all(env::var("OUT_DIR").unwrap()));
 
@@ -130,7 +140,7 @@ fn main() {
 
     // Make sure libssh2 was detected on unix systems, because it definitely
     // should have been!
-    if ssh && !msvc {
+    if ssh && !ssh_forced {
         let flags = dst.join("build/src/git2/sys/features.h");
         let mut contents = String::new();
         t!(t!(File::open(flags)).read_to_string(&mut contents));
@@ -177,7 +187,9 @@ fn main() {
 
 fn register_dep(dep: &str) {
     if let Some(s) = env::var_os(&format!("DEP_{}_ROOT", dep)) {
-        prepend("PKG_CONFIG_PATH", Path::new(&s).join("lib/pkgconfig"));
+        if !cfg!(target_env = "msvc") {
+            prepend("PKG_CONFIG_PATH", Path::new(&s).join("lib/pkgconfig"));
+        }
         return
     }
     if let Some(s) = env::var_os(&format!("DEP_{}_INCLUDE", dep)) {
@@ -185,7 +197,9 @@ fn register_dep(dep: &str) {
         env::set_var(&format!("DEP_{}_ROOT", dep), root);
         let path = root.join("lib/pkgconfig");
         if path.exists() {
-            prepend("PKG_CONFIG_PATH", path);
+            if !cfg!(target_env = "msvc") {
+                prepend("PKG_CONFIG_PATH", path);
+            }
             return
         }
     }
@@ -197,3 +211,20 @@ fn prepend(var: &str, val: PathBuf) {
     v.extend(env::split_paths(&prefix));
     env::set_var(var, &env::join_paths(v).unwrap());
 }
+
+fn sanitize_sh(path: &Path) -> String {
+    let path = path.to_str().unwrap().replace("\\", "/");
+    return change_drive(&path).unwrap_or(path);
+
+    fn change_drive(s: &str) -> Option<String> {
+        let mut ch = s.chars();
+        let drive = ch.next().unwrap_or('C');
+        if ch.next() != Some(':') {
+            return None
+        }
+        if ch.next() != Some('/') {
+            return None
+        }
+        Some(format!("/{}/{}", drive, &s[drive.len_utf8() + 2..]))
+    }
+}
